summaryrefslogtreecommitdiff
path: root/django/core/xheaders.py
diff options
context:
space:
mode:
Diffstat (limited to 'django/core/xheaders.py')
-rw-r--r--django/core/xheaders.py13
1 files changed, 6 insertions, 7 deletions
diff --git a/django/core/xheaders.py b/django/core/xheaders.py
index 98d2586b75..e173bcbca8 100644
--- a/django/core/xheaders.py
+++ b/django/core/xheaders.py
@@ -9,14 +9,13 @@ that custom headers are prefxed with "X-").
Next time you're at slashdot.org, watch out for X-Fry and X-Bender. :)
"""
-def populate_xheaders(request, response, package, python_module_name, object_id):
+def populate_xheaders(request, response, model, object_id):
"""
Adds the "X-Object-Type" and "X-Object-Id" headers to the given
- HttpResponse according to the given package, python_module_name and
- object_id -- but only if the given HttpRequest object has an IP address
- within the INTERNAL_IPS setting.
+ HttpResponse according to the given model and object_id -- but only if the
+ given HttpRequest object has an IP address within the INTERNAL_IPS setting.
"""
- from django.conf.settings import INTERNAL_IPS
- if request.META.get('REMOTE_ADDR') in INTERNAL_IPS:
- response['X-Object-Type'] = "%s.%s" % (package, python_module_name)
+ from django.conf import settings
+ if request.META.get('REMOTE_ADDR') in settings.INTERNAL_IPS:
+ response['X-Object-Type'] = "%s.%s" % (model._meta.app_label, model._meta.object_name.lower())
response['X-Object-Id'] = str(object_id)